#! /usr/bin/perl

use strict;
use warnings;
use Module::Build;

my $builder = Module::Build->subclass(
    class => "My::Module::Build",
    code  => <<'___CODE',
    use strict;
    use warnings;
    use File::Path;
    sub ACTION_build {
	my $self = shift;
	mkpath(qw(tmp/bind/master tmp/bind/zones.d));
	$self->SUPER::ACTION_build;
    }
    sub ACTION_realclean {
	my $self = shift;
	rmtree(qw(tmp/bind/master tmp/bind/zones.d), { safe => 1 });
	map { rmdir } qw(tmp/bind tmp);
	$self->SUPER::ACTION_realclean;
    }
___CODE
);

my $build = $builder->new(
    module_name    => "dnstools",
    dist_abstract  => "our dns tools",
    dist_author    => "schlittermann.de",
    dist_version   => "0.1.1",
    create_license => 1,
    license        => "gpl",
    requires       => {
        perl            => "5.10.0",
        "Net::LibIDN"   => "0",
        "Template"      => "0",
        "Net::DNS"      => "0",
        "Net::DNS::SEC" => "0",
    },
    script_files => [glob "bin/*"],    # avoid .swp files
    sbin_files => { map { /\.(bak|orig)$/ ? () : ($_ => $_) } glob("sbin/*") },
    nagios_files => { 'dnsnagios/check_dnssec' => 'sbin/check_dnssec' },
);

$build->add_build_element('sbin');
$build->add_build_element('nagios');
$build->install_path(
    'sbin' => $build->original_prefix($build->installdirs) . '/sbin');
$build->create_build_script;
